summaryrefslogtreecommitdiffstats
path: root/src/include/novel_types.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/novel_types.h')
-rwxr-xr-xsrc/include/novel_types.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/include/novel_types.h b/src/include/novel_types.h
index 17af150..9265cfe 100755
--- a/src/include/novel_types.h
+++ b/src/include/novel_types.h
@@ -86,7 +86,9 @@ enum PhraseIndexError{
ERROR_OK = 0, /* operate ok */
ERROR_NO_SUB_PHRASE_INDEX, /* sub phrase index is not loaded */
ERROR_NO_ITEM, /* item has a null slot */
- ERROR_OUT_OF_RANGE /* beyond the end of the sub phrase index */
+ ERROR_OUT_OF_RANGE, /* beyond the end of the sub phrase index */
+ ERROR_FILE_CORRUPTION, /* file is corrupted */
+ ERROR_INTEGER_OVERFLOW /* integer is overflowed */
};
/*